@@ -49,8 +49,6 @@ class Choam:
       f"{directory}\\README.md": f"# {name}\n#### This project was constructed with [Choam](https://github.com/cowboycodr/choam)",
       f"{directory}\\.gitignore": gitignore
     }
-
-    print(template)
     
     FS.construct_from_dict(template, directory)
   
@@ -68,7 +66,7 @@ class Choam:
     template = {
       f"\\{folder_name}\\{folder_name}\\__main__.py": "",
       f"\\{folder_name}\\{folder_name}\\__init__.py": "__version__ == '0.1'",
-      f"\\{folder_name}\\Choam.toml": f'[package]\nname = "{name}"\nversion = "0.0.1"\ndescription = ""',
+      f"\\{folder_name}\\Choam.toml": f'[package]\nname = "{name}"\nversion = "0.0.1"\ndescription = ""\n\n[modules]\nchoam = "*"',
       f"\\{folder_name}\\README.md": f"# {name}\n#### This project was constructed with [Choam](https://github.com/cowboycodr/choam)",
       f"\\{folder_name}\\.gitignore": gitignore
     }
@@ -158,17 +156,12 @@ class Choam:
     
   def publish(self):
     self.add("twine")
+    self.add("wheel")
     self.install()
 
     Choam._log("Attempting real publication to https://test.pypi.org/legacy")
+    
     subprocess.call([sys.executable, "-m", "setup.py", "sdist", "bdist_wheel"])
-    subprocess.call([sys.executable, "-m", "twine", "upload", f"--repository-url", "https://test.pypi.org/legacy/", "dist/*"])
-
-    Choam._log_multiple([
-      "Test publication successful",
-      "Attempting real publication..."
-    ])
-
     subprocess.call([sys.executable, "-m", "twine", "upload", "dist/*"])
 
     Choam._log("Real publication successful")
